@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::XSLT;
-$XML::GrammarBase::Role::XSLT::VERSION = '0.2.4';
+$XML::GrammarBase::Role::XSLT::VERSION = '0.2.5';
 use strict;
 use warnings;
 
@@ -52,7 +52,7 @@ XML::GrammarBase::Role::XSLT - a parameterized role for XSLT conversions.
 
 =head1 VERSION
 
-version 0.2.4
+version 0.2.5
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,7 @@ version 0.2.4
 
 =head1 VERSION
 
-version 0.2.4
+version 0.2.5
 
 =head1 PARAMATERS
 
@@ -269,7 +269,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/xml-grammarbase/issues>
+L<https://github.com/shlomif/perl-XML-GrammarBase/issues>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -378,8 +378,8 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<https://github.com/shlomif/xml-grammarbase>
+L<https://github.com/shlomif/perl-XML-GrammarBase>
 
-  git clone git://github.com/shlomif/xml-grammarbase.git
+  git clone git://github.com/shlomif/perl-XML-GrammarBase.git
 
 =cut
